@@ -9,9 +9,10 @@
 use crate::messaging::{EndUser, MessageId};
 use crate::routing::XorName;
 use crate::types::ChunkAddress;
+use dashmap::mapref::entry::Entry;
+use dashmap::DashMap;
 use itertools::Itertools;
-use std::collections::hash_map::Entry;
-use std::collections::{BTreeSet, HashMap};
+use std::collections::BTreeSet;
 
 use crate::node::capacity::CHUNK_COPY_COUNT;
 
@@ -28,24 +29,24 @@ struct ReadOperation {
 }
 
 pub struct AdultLiveness {
-    ops: HashMap<MessageId, ReadOperation>,
-    pending_ops: HashMap<XorName, usize>,
-    closest_adults: HashMap<XorName, Vec<XorName>>,
+    ops: DashMap<MessageId, ReadOperation>,
+    pending_ops: DashMap<XorName, usize>,
+    closest_adults: DashMap<XorName, Vec<XorName>>,
 }
 
 impl AdultLiveness {
     pub fn new() -> Self {
         Self {
-            ops: HashMap::default(),
-            pending_ops: HashMap::default(),
-            closest_adults: HashMap::default(),
+            ops: DashMap::new(),
+            pending_ops: DashMap::new(),
+            closest_adults: DashMap::new(),
         }
     }
 
     // Inserts a new read operation
     // Returns false if the operation already existed.
     pub fn new_read(
-        &mut self,
+        &self,
         msg_id: MessageId,
         head_address: ChunkAddress,
         origin: EndUser,
@@ -68,31 +69,52 @@ impl AdultLiveness {
         new_operation
     }
 
-    pub fn retain_members_only(&mut self, current_members: BTreeSet<XorName>) {
-        let old_members = self.closest_adults.keys().cloned().collect::<Vec<_>>();
-        for name in old_members {
-            if !current_members.contains(&name) {
-                let _ = self.pending_ops.remove(&name);
-                let _ = self.closest_adults.remove(&name);
-                let message_ids = self.ops.keys().cloned().collect::<Vec<_>>();
-                // TODO(after T4): For write operations perhaps we need to write it to a different Adult
-                for msg_id in message_ids {
-                    self.remove_target(msg_id, &name);
+    pub fn retain_members_only(&self, current_members: BTreeSet<XorName>) {
+        let all_keys: Vec<_> = self
+            .closest_adults
+            .iter()
+            .map(|entry| *entry.key())
+            .collect();
+
+        let removed_members = all_keys
+            .iter()
+            .filter_map(|key| {
+                if !current_members.contains(key) {
+                    let _ = self.pending_ops.remove(key);
+                    let _ = self.closest_adults.remove(key);
+                    Some(*key)
+                } else {
+                    None
                 }
+            })
+            .collect::<Vec<_>>();
+
+        let message_ids = self
+            .ops
+            .iter()
+            .map(|entry| *entry.key())
+            .collect::<Vec<_>>();
+
+        for name in removed_members {
+            // TODO(after T4): For write operations perhaps we need to write it to a different Adult
+            for msg_id in &message_ids {
+                self.remove_target(msg_id, &name);
             }
         }
+
         self.recompute_closest_adults();
     }
 
-    pub fn remove_target(&mut self, msg_id: MessageId, name: &XorName) {
-        if let Some(count) = self.pending_ops.get_mut(name) {
+    pub fn remove_target(&self, msg_id: &MessageId, name: &XorName) {
+        if let Some(mut count) = self.pending_ops.get_mut(name) {
             let counter = *count;
             if counter > 0 {
+                let count = count.value_mut();
                 *count -= 1;
             }
         }
-        let complete = if let Some(operation) = self.ops.get_mut(&msg_id) {
-            let ReadOperation { targets, .. } = operation;
+        let complete = if let Some(mut op) = self.ops.get_mut(&msg_id) {
+            let ReadOperation { targets, .. } = op.value_mut();
             let _ = targets.remove(name);
             targets.is_empty()
         } else {
@@ -104,20 +126,20 @@ impl AdultLiveness {
     }
 
     pub fn record_adult_read_liveness(
-        &mut self,
-        correlation_id: MessageId,
+        &self,
+        correlation_id: &MessageId,
         src: &XorName,
         success: bool,
     ) -> Option<(ChunkAddress, EndUser)> {
         self.remove_target(correlation_id, src);
         let op = self.ops.get_mut(&correlation_id);
-        op.and_then(|op| {
+        op.and_then(|mut op| {
             let ReadOperation {
                 head_address,
                 origin,
                 targets,
                 responded_with_success,
-            } = op;
+            } = op.value_mut();
 
             if targets.len() < CHUNK_COPY_COUNT && *responded_with_success {
                 None
@@ -128,50 +150,68 @@ impl AdultLiveness {
         })
     }
 
-    fn increment_pending_op(&mut self, targets: &BTreeSet<XorName>) {
+    fn increment_pending_op(&self, targets: &BTreeSet<XorName>) {
+        let mut closest_changed = false;
+
         for node in targets {
-            *self.pending_ops.entry(*node).or_insert(0) += 1;
-            if !self.closest_adults.contains_key(node) {
-                let _ = self.closest_adults.insert(*node, Vec::new());
-                self.recompute_closest_adults();
+            if !self.pending_ops.contains_key(node) {
+                let _ = self.pending_ops.insert(*node, 1);
             }
+            if let Some(mut pair) = self.pending_ops.get_mut(node) {
+                *pair.value_mut() += 1;
+            }
+            if !self.closest_adults.contains_key(node) {
+                closest_changed = true;
+                let _ = self.closest_adults.insert(*node, Vec::new());
+            }
+        }
+
+        if closest_changed {
+            self.recompute_closest_adults();
         }
     }
 
-    pub fn recompute_closest_adults(&mut self) {
-        let closest_adults_collection = self
+    pub fn recompute_closest_adults(&self) {
+        let all_keys: Vec<_> = self
             .closest_adults
             .iter()
-            .map(|(key, _)| {
-                let closest_adults = self
-                    .closest_adults
-                    .keys()
-                    .filter(|name| key != *name)
-                    .sorted_by(|lhs, rhs| key.cmp_distance(lhs, rhs))
-                    .take(NEIGHBOUR_COUNT)
-                    .copied()
-                    .collect::<Vec<_>>();
-
-                (key.to_owned(), closest_adults)
-            })
-            .collect::<Vec<(XorName, Vec<XorName>)>>();
-
-        self.closest_adults.extend(closest_adults_collection);
+            .map(|entry| *entry.key())
+            .collect();
+        self.closest_adults.alter_all(|name, _| {
+            all_keys
+                .iter()
+                .filter(|&key| key != name)
+                .sorted_by(|lhs, rhs| name.cmp_distance(lhs, rhs))
+                .take(NEIGHBOUR_COUNT)
+                .copied()
+                .collect::<Vec<_>>()
+        });
     }
 
+    // this is not an exact definition, thus has tolerance for variance due to concurrency
     pub fn find_unresponsive_adults(&self) -> Vec<(XorName, usize)> {
         let mut unresponsive_adults = Vec::new();
-        for (adult, neighbours) in &self.closest_adults {
+        for entry in &self.closest_adults {
+            let (adult, neighbours) = entry.pair();
             if let Some(max_pending_by_neighbours) = neighbours
                 .iter()
-                .map(|neighbour| self.pending_ops.get(neighbour).unwrap_or(&0))
+                .map(|neighbour| {
+                    self.pending_ops
+                        .get(neighbour)
+                        .map(|entry| *entry.value())
+                        .unwrap_or(0)
+                })
                 .max()
             {
-                let adult_pending_ops = *self.pending_ops.get(adult).unwrap_or(&0);
+                let adult_pending_ops = self
+                    .pending_ops
+                    .get(adult)
+                    .map(|entry| *entry.value())
+                    .unwrap_or(0);
                 if adult_pending_ops > MIN_PENDING_OPS
-                    && max_pending_by_neighbours > &MIN_PENDING_OPS
+                    && max_pending_by_neighbours > MIN_PENDING_OPS
                     && adult_pending_ops as f64 * PENDING_OP_TOLERANCE_RATIO
-                        > *max_pending_by_neighbours as f64
+                        > max_pending_by_neighbours as f64
                 {
                     tracing::info!(
                         "Pending ops for {}: {} Neighbour max: {}",
