@@ -44,7 +44,7 @@ impl ElderStores {
     }
 
     pub async fn read(
-        &mut self,
+        &self,
         query: DataQuery,
         msg_id: MessageId,
         requester: PublicKey,
@@ -121,10 +121,6 @@ impl ElderStores {
         &self.chunk_records
     }
 
-    pub fn chunk_records_mut(&mut self) -> &mut ChunkRecords {
-        &mut self.chunk_records
-    }
-
     // NB: Not yet including Register metadata.
     pub async fn get_data_of(&self, prefix: Prefix) -> Result<DataExchange> {
         // Prepare chunk_records, map and sequence data
